---
title: 헥토파이낸셜 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
seo:
  title: 헥토파이낸셜 채널설정방법
  description: >-
    헥토파이낸셜 연동을 위한 채널 설정 방법을 안내드립니다. '테스트 연동, 실 연동' 순으로 이뤄지며, 채널 설정 없이 결제 연동을 하실
    경우 정상적인 호출이 불가하며, 오류가 발생됩니다.
  keywords:
    - 헥토파이낸셜
    - 일반결제
    - 정기결제
    - 내통장결제
    - 결제연동
    - 채널설정방법
    - 채널추가
tags:
  - 헥토파이낸셜
  - 결제
  - 채널설정방법
pgCompanies:
  - 헥토파이낸셜
searchTags:
  - 헥토파이낸셜 테스트연동
  - 헥토파이낸셜 실연동
  - 헥토파이낸셜 테스트모드
  - 헥토하이낸셜 실연동
  - 헥토파이낸셜 실모드
  - 헥토 일반결제
  - 헥토 정기결제
  - 내통장결제
  - 가상계좌 API
  - 세틀뱅크
  - 핵토파이낸셜(세틀뱅크)
  - 일반결제
  - 핵토파이낸셜 일반결제
  - 헥토파이낸셜 정기결제
datetime: 2023-12-19T15:00:00.000Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Highlight url="#7_내통장결제" text="헥토파이낸셜 내통장결제 설정 바로가기↓" />

<Callout content="[연동방식]
- 결제창 : 결제대행사(PG사)의 결제창을 띄워서 그 안에서 결제수단 선택 후 결제하는 방식
- API : 직접 구현한 UI를 통해 결제 수단 정보를 입력받아 API를 통해 결제하는 방식

[모듈버전]
- V1 : 포트원 결제모듈 V1. 다양한 결제대행사와 수단을 지원
- V2 : 포트원 차세대 결제 모듈로 직관적인 인터페이스를 지원
- 신모듈 : 결제대행사의 최신 버전의 모듈
- 구모듈 : 결제대행사의 구 버전의 모듈

[결제방식]
- 일반결제 : 구매자의 결제정보를 저장하지 않는 일회성 결제 (단건결제)
- 정기결제 : 구매자의 결제정보를 저장해놓고 재결제하는 결제 (정기 / 비 정기결제)
" title="참고사항" icon="💡" />

## <Highlight text="결제창 일반결제 및 API 수기/정기결제" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 바로가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="헥토파이낸셜 테스트 모드의 경우 실제 출금 되지만 매일 23:00~23:50분 사이 자동 취소됩니다.
" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 헥토파이낸셜
  - 결제모듈 : 결제창 일반결제 및 API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) 클릭
  - 결제창 일반결제  : portone1 선택
  - API 수기결제-신용카드\_카유비생 : nxca\_ks\_gu 선택
    - \[카드번호, 유효기간, 비밀번호 앞 2자리, 생년월일] 정보를 기입하는 수기결제
  - API 수기결제-신용카드\_카유 : nxca\_jt\_bi 선택
    - \[카드번호, 유효기간] 정보를 기입하는 수기결제
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)

<Callout content="**[가상계좌를 이용하는 경우 필수 설정 사항]**
PG계약이 완료되신 경우, MID를 발급받으신 후 헥토파이낸셜측으로 가상계좌 입금통보 URL 요청 메일을 발송하여주시기 바랍니다.
- 보내실 이메일 주소 : settle_pgdev@hecto.co.kr
- 상호명 : 기재 후 헥토파이낸셜측으로 요청바랍니다.
- 상점아이디(MID) : 기재 후 헥토파이낸셜측으로 요청바랍니다.
- 가상계좌 입금통보설정 : https://service.iamport.kr/settle_payments/notice_vbank
- **헥토파이낸셜 상점아이디 : imp_****** (**imp_ 다음 4자리를 설정해주시기 바랍니다. 총 8자리**)" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 :  실 연동
  - 결제대행사 : 헥토파이낸셜
  - 결제모듈 : 결제창 일반결제 및 API 수기/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) : 헥토파이낸셜과 계약 후 발급받으신 상점아이디(MID)
- 라이센스키 (전문 해쉬 키) : 헥토파이낸셜과 계약 후 발급받으신 해쉬키
- 암호화 키 : 헥토파이낸셜과 계약 후 발급받으신 암호화 키
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

<Callout title="헥토파이낸셜 개발가이드 보러가기↗" icon="" />

## <Highlight text="내통장결제" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 바로가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 헥토파이낸셜
  - 결제모듈 : 내통장결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) : 헥토파이낸셜의 내통장결제의 경우 범용 테스트 상점아이디를 제공하지 않아 고객사별로 헥토파이낸셜과 계약 후 테스트 MID를 발급받아 테스트 연동 개발 진행 가능합니다.
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : 헥토파이낸셜
  - 결제모듈 : 내통장결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) : 헥토파이낸셜과 계약 후 발급받으신 상점아이디(MID)
- 라이센스키 (전문 해쉬 키) : 헥토파이낸셜과 계약 후 발급받으신 해쉬키
- 암호화 키 : 헥토파이낸셜과 계약 후 발급받으신 암호화 키
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

<Callout title="헥토파이낸셜 내통장결제 개발가이드 보러가기↗" />
